@@ -1,15 +1,13 @@
 # coding=utf-8
 
 import os
-from os.path import join
 from collections import defaultdict
+from os.path import join
 
 from sqlalchemy.schema import MetaData
 
-from guniflask_cli.sqlgen import SqlToModelGenerator
 from guniflask_cli.errors import UsageError
-from guniflask_cli.env import get_project_name_from_env, load_app_env
-from guniflask_cli.config import load_app_settings
+from guniflask_cli.sqlgen import SqlToModelGenerator
 from .base import Command
 
 
@@ -37,12 +35,8 @@ class TableToModel(Command):
 
     def run(self, args):
         from guniflask.app import create_app
-
-        load_app_env()
-        project_name = get_project_name_from_env()
-        settings = load_app_settings(project_name)
-
-        app = create_app(project_name, settings=settings, with_context=False)
+        app = create_app(with_context=False)
+        app_name = app.name
         with app.app_context():
             settings = app.settings
             s = app.extensions.get('sqlalchemy')
@@ -53,9 +47,9 @@ class TableToModel(Command):
             binds = [None] + list(app.config.get('SQLALCHEMY_BINDS') or ())
             for b in binds:
                 if b is None:
-                    default_dest[b] = {'dest': join(project_name, 'models')}
+                    default_dest[b] = {'dest': join(app_name, 'models')}
                 else:
-                    default_dest[b] = {'dest': join(project_name, f'models_{b}')}
+                    default_dest[b] = {'dest': join(app_name, f'models_{b}')}
             dest_config = settings.get_by_prefix('guniflask.table2model_dest', default_dest)
             if isinstance(dest_config, str):
                 default_dest[None]['dest'] = dest_config
@@ -73,5 +67,5 @@ class TableToModel(Command):
                 engine = db.get_engine(bind=b)
                 metadata = MetaData(engine)
                 metadata.reflect()
-                gen = SqlToModelGenerator(project_name, metadata, bind=b)
+                gen = SqlToModelGenerator(app_name, metadata, bind=b)
                 gen.render(join(settings['home'], c.get('dest')))
