@@ -1,17 +1,14 @@
 # coding=utf-8
 
-import os
-from os.path import join, dirname, exists
-from functools import partial
 import logging
-import getpass
+import os
+from functools import partial
+from os.path import join, dirname, exists
 
-from gunicorn.config import KNOWN_SETTINGS
 from gunicorn.app.base import Application
+from gunicorn.config import KNOWN_SETTINGS
 
-from .config import load_profile_config, load_app_settings
 from .utils import walk_files, redirect_app_logger, redirect_logger
-from .env import get_project_name_from_env, load_app_env
 
 
 class GunicornApplication(Application):
@@ -25,57 +22,55 @@ class GunicornApplication(Application):
             self.cfg.set(key, value)
 
     def load_config(self):
+        from guniflask.config import set_app_default_env
+        set_app_default_env()
         self.options = self._make_options(self.options)
         for key, value in self.options.items():
             if key in self.cfg.settings and value is not None:
                 self.cfg.set(key.lower(), value)
+        self._set_default_env()
 
     def load(self):
         from guniflask.app import create_app
-
-        self._set_default_env()
-        load_app_env()
-        app_name = get_project_name_from_env()
-        app_settings = load_app_settings(app_name)
+        app = create_app()
 
         gunicorn_logger = logging.getLogger('gunicorn.error')
         redirect_logger('guniflask', gunicorn_logger)
-        redirect_logger(app_name, gunicorn_logger)
-        app = create_app(app_name, settings=app_settings)
+        redirect_logger(app.name, gunicorn_logger)
         redirect_app_logger(app, gunicorn_logger)
 
-        return app.asgi_app
+        return app
 
     def _make_options(self, opt: dict):
-        pid_dir = os.environ['GUNIFLASK_PID_DIR']
-        log_dir = os.environ['GUNIFLASK_LOG_DIR']
-        project_name = get_project_name_from_env()
-        username = getpass.getuser()
+        from guniflask.config import app_name_from_env
+        home_dir = os.environ.get('GUNIFLASK_HOME')
+        pid_dir = join(home_dir, '.pid')
+        log_dir = join(home_dir, '.log')
+        app_name = app_name_from_env()
         options = {
             'daemon': True,
             'workers': os.cpu_count(),
-            'worker_class': 'guniflask_cli.workers.UvicornWorker',
-            'accesslog': join(log_dir, f'{project_name}-{username}.access.log'),
-            'errorlog': join(log_dir, f'{project_name}-{username}.error.log'),
-            'proc_name': project_name
+            'worker_class': 'gevent',
+            'accesslog': join(log_dir, f'{app_name}.access.log'),
+            'errorlog': join(log_dir, f'{app_name}.error.log'),
+            'proc_name': app_name
         }
         profile_options = self._make_profile_options(os.environ.get('GUNIFLASK_ACTIVE_PROFILES'))
-        if 'worker_class' in profile_options and profile_options['worker_class'] != options['worker_class']:
-            raise ValueError(f'worker_class cannot be set to: {profile_options["worker_class"]}')
         options.update(profile_options)
         # if debug
         if os.environ.get('GUNIFLASK_DEBUG'):
-            options.update(self._make_debug_options())
+            self._update_debug_options(options)
         options.update(opt)
         # pid file
         if 'pidfile' not in options and options.get('daemon'):
-            options['pidfile'] = join(pid_dir, f'{project_name}-{username}.pid')
+            options['pidfile'] = join(pid_dir, f'{app_name}.pid')
         self._makedirs(options)
         # hook wrapper
         HookWrapper.wrap(options)
         return options
 
     def _make_profile_options(self, active_profiles):
+        from guniflask.config import load_profile_config
         conf_dir = os.environ['GUNIFLASK_CONF_DIR']
         gc = load_profile_config(conf_dir, 'gunicorn', profiles=active_profiles)
         settings = {}
@@ -86,18 +81,20 @@ class GunicornApplication(Application):
         return settings
 
     @staticmethod
-    def _make_debug_options():
+    def _update_debug_options(options: dict):
         conf_dir = os.environ['GUNIFLASK_CONF_DIR']
-        return {
+        opt = {
             'accesslog': '-',
             'errorlog': '-',
             'loglevel': 'debug',
-            'disable_redirect_access_to_syslog': True,
             'reload': True,
             'reload_extra_files': walk_files(conf_dir),
             'workers': 1,
             'daemon': False
         }
+        if 'reload_extra_files' in options:
+            opt['reload_extra_files'].extend(options['reload_extra_files'])
+        options.update(opt)
 
     @staticmethod
     def _makedirs(opts):
