@@ -2,20 +2,22 @@
 
 import logging
 
+from flask import Flask
 from flask_sqlalchemy import SQLAlchemy
+from guniflask.config import Settings
 
 log = logging.getLogger(__name__)
 
 db = SQLAlchemy()
 
 
-def make_settings(app, settings):
+def make_settings(app: Flask, settings: Settings):
     """
     This function is invoked before initializing app.
     """
 
 
-def init_app(app, settings):
+def init_app(app: Flask, settings: Settings):
     """
     This function is invoked before running app.
     """
