@@ -1,29 +1,15 @@
 # coding=utf-8
 
-import sys
-import tty
-import termios
-import os
-from os.path import isfile, join, isdir
-from importlib import import_module
-from pkgutil import iter_modules
-import re
 import logging
+import os
+import re
+from importlib import import_module
+from os.path import isfile, join, isdir
+from pkgutil import iter_modules
 
 from flask import Flask
 
 
-def readchar():  # pragma: no cover
-    fd = sys.stdin.fileno()
-    old_settings = termios.tcgetattr(fd)
-    try:
-        tty.setraw(sys.stdin.fileno())
-        ch = sys.stdin.read(1)
-    finally:
-        termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
-    return ch
-
-
 def walk_modules(path: str):
     mods = []
     mod = import_module(path)
